pub type Methods = BTreeMap<String, MethodAuthorization>;Expand description
A set of methods that are subject to access control.
Aliased Type
pub struct Methods { /* private fields */ }pub type Methods = BTreeMap<String, MethodAuthorization>;A set of methods that are subject to access control.
pub struct Methods { /* private fields */ }