pub trait Config: 'static {
type EndorsementPolicyEvaluator: EndorsementPolicyEvaluator;
Show 17 associated constants and 0 method
const GAS_COST_CALL_CREATE: u64 = 100_000;
const GAS_COST_CALL_UPDATE: u64 = 100_000;
const GAS_COST_CALL_REMOVE: u64 = 10_000;
const GAS_COST_CALL_REGISTER: u64 = 100_000;
const GAS_COST_CALL_IS_AUTHORIZED_ORIGIN: u64 = 1000;
const GAS_COST_CALL_AUTHORIZED_ORIGIN_NODE: u64 = 2000;
const GAS_COST_CALL_AUTHORIZED_ORIGIN_ENTITY: u64 = 2000;
const GAS_COST_CALL_ORIGIN_APP: u64 = 1000;
const GAS_COST_CALL_STAKE_THRESHOLDS: u64 = 10;
const GAS_COST_CALL_DERIVE_KEY: u64 = 10_000;
const MAX_METADATA_PAIRS: usize = 64;
const MAX_METADATA_KEY_SIZE: usize = 1024;
const MAX_METADATA_VALUE_SIZE: usize = _;
const STAKE_APP_CREATE: BaseUnits = _;
const DERIVE_KEY_MAX_KEY_ID_LENGTH: usize = 128;
const MAX_ENDORSEMENT_POLICY_ATOMS: usize = 32;
const MAX_POLICY_EXPIRATION_EPOCHS: u64 = 24;
}Expand description
Module configuration.
Provided Associated Constants
Sourceconst GAS_COST_CALL_CREATE: u64 = 100_000
const GAS_COST_CALL_CREATE: u64 = 100_000
Gas cost of rofl.Create call.
Sourceconst GAS_COST_CALL_UPDATE: u64 = 100_000
const GAS_COST_CALL_UPDATE: u64 = 100_000
Gas cost of rofl.Update call.
Sourceconst GAS_COST_CALL_REMOVE: u64 = 10_000
const GAS_COST_CALL_REMOVE: u64 = 10_000
Gas cost of rofl.Remove call.
Sourceconst GAS_COST_CALL_REGISTER: u64 = 100_000
const GAS_COST_CALL_REGISTER: u64 = 100_000
Gas cost of rofl.Register call.
Sourceconst GAS_COST_CALL_IS_AUTHORIZED_ORIGIN: u64 = 1000
const GAS_COST_CALL_IS_AUTHORIZED_ORIGIN: u64 = 1000
Gas cost of rofl.IsAuthorizedOrigin call.
Sourceconst GAS_COST_CALL_AUTHORIZED_ORIGIN_NODE: u64 = 2000
const GAS_COST_CALL_AUTHORIZED_ORIGIN_NODE: u64 = 2000
Gas cost of rofl.AuthorizedOriginNode call.
Sourceconst GAS_COST_CALL_AUTHORIZED_ORIGIN_ENTITY: u64 = 2000
const GAS_COST_CALL_AUTHORIZED_ORIGIN_ENTITY: u64 = 2000
Gas cost of rofl.AuthorizedOriginEntity call.
Sourceconst GAS_COST_CALL_ORIGIN_APP: u64 = 1000
const GAS_COST_CALL_ORIGIN_APP: u64 = 1000
Gas cost of rofl.OriginApp call.
Sourceconst GAS_COST_CALL_STAKE_THRESHOLDS: u64 = 10
const GAS_COST_CALL_STAKE_THRESHOLDS: u64 = 10
Gas cost of rofl.StakeThresholds call.
Sourceconst GAS_COST_CALL_DERIVE_KEY: u64 = 10_000
const GAS_COST_CALL_DERIVE_KEY: u64 = 10_000
Gas cost of rofl.DeriveKey call.
Sourceconst MAX_METADATA_PAIRS: usize = 64
const MAX_METADATA_PAIRS: usize = 64
Maximum number of metadata key-value pairs.
Sourceconst MAX_METADATA_KEY_SIZE: usize = 1024
const MAX_METADATA_KEY_SIZE: usize = 1024
Maximum metadata key size.
Sourceconst MAX_METADATA_VALUE_SIZE: usize = _
const MAX_METADATA_VALUE_SIZE: usize = _
Maximum metadata value size.
Sourceconst STAKE_APP_CREATE: BaseUnits = _
const STAKE_APP_CREATE: BaseUnits = _
Amount of stake required for maintaining an application.
The stake is held in escrow and is returned to the administrator when the application is removed.
Sourceconst DERIVE_KEY_MAX_KEY_ID_LENGTH: usize = 128
const DERIVE_KEY_MAX_KEY_ID_LENGTH: usize = 128
Maximum key identifier length for rofl.DeriveKey call.
Sourceconst MAX_ENDORSEMENT_POLICY_ATOMS: usize = 32
const MAX_ENDORSEMENT_POLICY_ATOMS: usize = 32
Maximum number of endorsment policy atoms.
Sourceconst MAX_POLICY_EXPIRATION_EPOCHS: u64 = 24
const MAX_POLICY_EXPIRATION_EPOCHS: u64 = 24
Maximum value of the max_expiration field in the app policy (in epochs).
Required Associated Types
Sourcetype EndorsementPolicyEvaluator: EndorsementPolicyEvaluator
type EndorsementPolicyEvaluator: EndorsementPolicyEvaluator
Endorsement policy evaluator.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.